/***
 * uGASP: a gaming services platform for mobile multiplayer games.
 * GASP Demonstrator: a gasp demonstration game.
 *
 * Copyright (C) 2004 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin, Gabriel Adgeg
 */
package org.ugasp.impl.games.demonstrator;


import org.ugasp.impl.gamelogic.GameLogicImpl;
import org.ugasp.eventmodel.listener.OnEvent;
import org.ugasp.protocol.rmai.RMAIUtils;
import org.ugasp.logging.Logger;

/**
 * This class represents the game logic on the server side.
 * Each instance of your application is represented by an instance of this class, e.g.
 * if application model is set to "automatic" and N GASPClients call the createApplicationInstance method,
 * uGASP platform will create N instances of this class.
 * 
 * Behavior of game logic on the reception of in game events have to be put in several onEvent methods.
 * 
 * Properties are linked with this game logic, and can be set in metadata.xml 
 * (located in helloworld-demonstrator-gamelogic-maven/src/resources):
 * <ul>
 * <li>appID is the identifier of your application, which is needed when clients want to connect it</li>
 * <li>model is the model of instance for your application, which can be chosen between "automatic", "manual" and "permanent"</li>
 * <li>timeout is the time from which a client which stopped to communicate with the server is considered as disconnected, 
 * and thus raise a QuitEvent</li>
 * </ul>
 * 
 * @see GASPClient.createApplicationInstance
 * @author PELLERIN Romain (Ubidreams, romain.pellerin@ubidreams.com )
 * @author ADGEG Gabriel (Telecom Sud Paris, gabriel.adgeg@telecom-sudparis.eu)
 */
public class HelloworldGameLogicDemonstrator extends GameLogicImpl implements OnEvent{
	
	// iPojo injected fields
	private RMAIUtils rmaiUtils;
	private Logger logger;
	
	 
	public HelloworldGameLogicDemonstrator(){
		if(logger != null){
			logger.log(Logger.INFO,this.getClass(),"uGASP Helloworld Game Logic Demonstrator instantiated");
		}else{
			System.out.println("Error occured on the retrieval of logging service. Make sure it is properly started.");
		}	
	}
	
	
	@Override
	public Logger getLogger() {
		return logger;
	}
	
	@Override
	protected RMAIUtils getRMAIUtils() {
		return rmaiUtils;
	}

	@Override
	protected Object newRMAIGameLogicManager(short senderASID, short recipientASID) {
		return new MyRMAIGameLogicManager(this,senderASID,recipientASID);
	}
	
}
