package org.ugasp.impl.games.demonstrator;

import org.ugasp.logging.Logger;
import org.ugasp.protocol.rmai.RMAIGameLogicManager;


/**
 * This class holds the methods that will be invoked remotely by other clients.
 * 
 * Declare methods respecting following properties:
 * <ul>
 * <li>they must be instances methods, and not static ones</li>
 * <li>types handled as parameters are Byte, Short, Integer, Long, Float, Double, Boolean, String, RMAISerializable and arrays of all those types</li>
 * <li>as method invocations through RMAI protocol are asynchronous,
 * only void methods can be invoked. However a callback mechanism is provided, allowing to invoke remote method
 * on the entity which did the invocation first.</li>
 * </ul>
 * 
 * Entity which has invoked a method located in this class can be retrieved, using getSenderActorSessionID().
 **/
public class MyRMAIGameLogicManager extends RMAIGameLogicManager{

	private HelloworldGameLogicDemonstrator gameLogic;
	
	public MyRMAIGameLogicManager(HelloworldGameLogicDemonstrator gameLogic, short senderActorSessionID, short recipientActorSessionID){
		super(senderActorSessionID, recipientActorSessionID);
		this.gameLogic = gameLogic;
	}


	/*********************************************************************************************************/
	/*************************************    Remote Methods    **********************************************/
	/*********************************************************************************************************/	

	
	public void sendMessageToPlatform(String message){
		gameLogic.getLogger().log(Logger.INFO, getClass(), "Message received from actorSessionID: "+senderActorSessionID+" = "+message);
		sendMessageToClient(senderActorSessionID);
	}
	
	private void sendMessageToClient(short recipientActorSessionId){
		gameLogic.remoteMethodAsynchronousInvocation(recipientActorSessionId, "sendMessageToClient","Message received!");
	}
}
